@@ -52,11 +52,12 @@ To use these functions, do:
 
 import os
 import logging
+from satpy import config
 
 LOG = logging.getLogger(__name__)
 
 
-def get_us_midlatitude_cyclone_abi(base_dir='.', method=None, force=False):
+def get_us_midlatitude_cyclone_abi(base_dir=None, method=None, force=False):
     """Get GOES-16 ABI (CONUS sector) data from 2019-03-14 00:00Z.
 
     Args:
@@ -71,6 +72,7 @@ def get_us_midlatitude_cyclone_abi(base_dir='.', method=None, force=False):
     Total size: ~110MB
 
     """
+    base_dir = base_dir or config.get('demo_data_dir', '.')
     if method is None:
         method = 'gcsfs'
     if method not in ['gcsfs']:
@@ -86,7 +88,7 @@ def get_us_midlatitude_cyclone_abi(base_dir='.', method=None, force=False):
     return filenames
 
 
-def get_hurricane_florence_abi(base_dir='.', method=None, force=False,
+def get_hurricane_florence_abi(base_dir=None, method=None, force=False,
                                channels=None, num_frames=10):
     """Get GOES-16 ABI (Meso sector) data from 2018-09-11 13:00Z to 17:00Z.
 
@@ -110,6 +112,7 @@ def get_hurricane_florence_abi(base_dir='.', method=None, force=False,
     Total size (240 frames, all channels): ~3.5GB
 
     """
+    base_dir = base_dir or config.get('demo_data_dir', '.')
     if channels is None:
         channels = range(1, 17)
     if method is None:
@@ -142,3 +145,38 @@ def get_hurricane_florence_abi(base_dir='.', method=None, force=False,
     num_frames = int((actual_slice[1] - actual_slice[0]) / actual_slice[2])
     assert len(filenames) == len(channels) * num_frames, "Not all files could be downloaded"
     return filenames
+
+
+def download_typhoon_surigae_ahi(base_dir=None,
+                                 channels=(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16),
+                                 segments=(1, 2, 3, 4, 5, 6, 7, 8, 9, 10)):
+    """Download Himawari 8 data.
+
+    This scene shows the Typhoon Surigae.
+    """
+    import s3fs
+    base_dir = base_dir or config.get('demo_data_dir', '.')
+    channel_resolution = {1: 10,
+                          2: 10,
+                          3: 5,
+                          4: 10}
+    data_files = []
+    for channel in channels:
+        for segment in segments:
+            resolution = channel_resolution.get(channel, 20)
+            data_files.append(f"HS_H08_20210417_0500_B{channel:02d}_FLDK_R{resolution:02d}_S{segment:02d}10.DAT.bz2")
+
+    subdir = os.path.join(base_dir, 'ahi_hsd', '20210417_0500_random')
+    os.makedirs(subdir, exist_ok=True)
+    fs = s3fs.S3FileSystem(anon=True)
+
+    result = []
+    for filename in data_files:
+        destination_filename = os.path.join(subdir, filename)
+        result.append(destination_filename)
+        if os.path.exists(destination_filename):
+            continue
+        to_get = 'noaa-himawari8/AHI-L1b-FLDK/2021/04/17/0500/' + filename
+        fs.get_file(to_get, destination_filename)
+
+    return result
