@@ -18,6 +18,7 @@
 """Tests for the satpy.demo module."""
 
 import os
+import sys
 import unittest
 from unittest import mock
 
@@ -171,3 +172,23 @@ class TestGCPUtils(unittest.TestCase):
         """Test that 'gcsfs' is required."""
         from satpy.demo._google_cloud_platform import get_bucket_files
         self.assertRaises(RuntimeError, get_bucket_files, '*.nc', '.')
+
+
+class TestAHIDemoDownload:
+    """Test the AHI demo data download."""
+
+    @mock.patch.dict(sys.modules, {'s3fs': mock.MagicMock()})
+    def test_ahi_full_download(self):
+        """Test that the himawari download works as expected."""
+        from satpy.demo import download_typhoon_surigae_ahi
+        from tempfile import gettempdir
+        files = download_typhoon_surigae_ahi(base_dir=gettempdir())
+        assert len(files) == 160
+
+    @mock.patch.dict(sys.modules, {'s3fs': mock.MagicMock()})
+    def test_ahi_partial_download(self):
+        """Test that the himawari download works as expected."""
+        from satpy.demo import download_typhoon_surigae_ahi
+        from tempfile import gettempdir
+        files = download_typhoon_surigae_ahi(base_dir=gettempdir(), segments=[4, 9], channels=[1, 2, 3])
+        assert len(files) == 6
