@@ -17,9 +17,14 @@
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
 """Testing of utils."""
 
+import logging
 import unittest
+import warnings
 from unittest import mock
+
+import pytest
 from numpy import sqrt
+
 from satpy.utils import angle2xyz, lonlat2xyz, xyz2angle, xyz2lonlat, proj_units_to_meters, get_satpos
 
 
@@ -285,3 +290,70 @@ def test_make_fake_scene():
             attrs={"please": "preserve", "answer": 42})},
         common_attrs={"bad words": "semprini bahnhof veerooster winterbanden"})
     assert sc["nine"].attrs.keys() >= {"please", "answer", "bad words", "area"}
+
+
+class TestCheckSatpy(unittest.TestCase):
+    """Test the 'check_satpy' function."""
+
+    def test_basic_check_satpy(self):
+        """Test 'check_satpy' basic functionality."""
+        from satpy.utils import check_satpy
+        check_satpy()
+
+    def test_specific_check_satpy(self):
+        """Test 'check_satpy' with specific features provided."""
+        from satpy.utils import check_satpy
+        with mock.patch('satpy.utils.print') as print_mock:
+            check_satpy(readers=['viirs_sdr'], extras=('cartopy', '__fake'))
+            checked_fake = False
+            for call in print_mock.mock_calls:
+                if len(call[1]) > 0 and '__fake' in call[1][0]:
+                    self.assertNotIn('ok', call[1][1])
+                    checked_fake = True
+            self.assertTrue(checked_fake, "Did not find __fake module "
+                                          "mentioned in checks")
+
+
+def test_debug_on(caplog):
+    """Test that debug_on is working as expected."""
+    from satpy.utils import debug_on, debug_off, debug
+
+    def depwarn():
+        logger = logging.getLogger("satpy.silly")
+        logger.debug("But now it's just got SILLY.")
+        warnings.warn("Stop that! It's SILLY.", DeprecationWarning)
+    warnings.filterwarnings("ignore", category=DeprecationWarning)
+    debug_on(False)
+    filts_before = warnings.filters.copy()
+    # test that logging on, but deprecation warnings still off
+    with caplog.at_level(logging.DEBUG):
+        depwarn()
+    assert warnings.filters == filts_before
+    assert "But now it's just got SILLY." in caplog.text
+    debug_on(True)
+    # test that logging on and deprecation warnings on
+    with pytest.warns(DeprecationWarning):
+        depwarn()
+    assert warnings.filters != filts_before
+    debug_off()  # other tests assume debugging is off
+    # test that filters were reset
+    assert warnings.filters == filts_before
+    with debug():
+        assert warnings.filters != filts_before
+    assert warnings.filters == filts_before
+
+
+def test_logging_on_and_off(caplog):
+    """Test that switching logging on and off works."""
+    from satpy.utils import logging_on, logging_off
+    logger = logging.getLogger("satpy.silly")
+    logging_on()
+    with caplog.at_level(logging.WARNING):
+        logger.debug("I'd like to leave the army please, sir.")
+        logger.warning("Stop that!  It's SILLY.")
+    assert "Stop that!  It's SILLY" in caplog.text
+    assert "I'd like to leave the army please, sir." not in caplog.text
+    logging_off()
+    with caplog.at_level(logging.DEBUG):
+        logger.warning("You've got a nice army base here, Colonel.")
+    assert "You've got a nice army base here, Colonel." not in caplog.text
