@@ -80,6 +80,7 @@ The metadata to provide to the writer can also be stored in a configuration file
 import logging
 
 import numpy as np
+import xarray as xr
 
 import pyninjotiff.ninjotiff as nt
 from satpy.writers import ImageWriter
@@ -90,23 +91,43 @@ logger = logging.getLogger(__name__)
 
 
 def convert_units(dataset, in_unit, out_unit):
-    """Convert units of *dataset*."""
-    from pint import UnitRegistry
+    """Convert units of *dataset*.
 
-    ureg = UnitRegistry()
-    # Commented because buggy: race condition ?
-    # ureg.define("degree_Celsius = degC = Celsius = C = CELSIUS")
-    in_unit = ureg.parse_expression(in_unit, False)
-    if out_unit in ['CELSIUS', 'C', 'Celsius', 'celsius']:
-        dest_unit = ureg.degC
-    else:
-        dest_unit = ureg.parse_expression(out_unit, False)
-    data = ureg.Quantity(dataset, in_unit)
-    attrs = dataset.attrs
-    dataset = data.to(dest_unit).magnitude
-    dataset.attrs = attrs
-    dataset.attrs["units"] = out_unit
-    return dataset
+    Convert dataset units for the benefit of writing NinJoTIFF.  The main
+    background here is that NinJoTIFF would like brightness temperatures in °C,
+    but satellite data files are in K.  For simplicity of implementation, this
+    function can only convert from K to °C.
+
+    This function will convert input data from K to °C and write the new unit
+    in the ``"units"`` attribute.  When output and input units are equal, it
+    returns the input dataset.
+
+    Args:
+        dataset (xarray DataArray):
+            Dataarray for which to convert the units.
+        in_unit (str):
+            Unit for input data.
+        out_unit (str):
+            Unit for output data.
+
+    Returns:
+        dataset, possibly with new units.
+    """
+    if in_unit == out_unit:
+        return dataset
+
+    if in_unit.lower() in {"k", "kelvin"} and out_unit.lower() in {"c", "celsius"}:
+        with xr.set_options(keep_attrs=True):
+            new_dataset = dataset + 273.15
+        new_dataset.attrs["units"] = out_unit
+        return new_dataset
+
+    # Other units not implemented.  Before Satpy 0.16.1 there was a
+    # non-working implementation based on pint here.
+
+    raise NotImplementedError(
+            "NinJoTIFF unit conversion only implemented between K and C, not "
+            f"between {in_unit!s} and {out_unit!s}")
 
 
 class NinjoTIFFWriter(ImageWriter):
